@@ -8,17 +8,17 @@ use Carp ;
 use IO::Handle ;
 use Scalar::Util qw(dualvar);
 
-use IO::Compress::Base::Common ;
-use Compress::Raw::Zlib;
-use IO::Compress::Gzip;
-use IO::Uncompress::Gunzip;
+use IO::Compress::Base::Common 2.003 ;
+use Compress::Raw::Zlib 2.003 ;
+use IO::Compress::Gzip 2.003 ;
+use IO::Uncompress::Gunzip 2.003 ;
 
 use strict ;
 use warnings ;
 use bytes ;
 our ($VERSION, $XS_VERSION, @ISA, @EXPORT, $AUTOLOAD);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $XS_VERSION = $VERSION; 
 $VERSION = eval $VERSION;
 
@@ -438,7 +438,7 @@ sub inflate
 
 package Compress::Zlib ;
 
-use IO::Compress::Gzip::Constants;
+use IO::Compress::Gzip::Constants 2.003 ;
 
 sub memGzip($)
 {
@@ -1452,7 +1452,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 1995-2006 Paul Marquess. All rights reserved.
+Copyright (c) 1995-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
